::+=============================================================================
::
:: Name:        GetTaskList.bat
:: Type:        User Command Task
:: Language:    MS-DOS Batch
:: Index:       Generates running system info useful for diagnosing problems.
::
::
:: Function:
::
::      This procedure is intended to be scheduled periodically, and its output 
::      generated on different dates can be used by comparison to help determine 
::      if something's running that didn't used to be running, a service config
::      has changed, or a scheduled task has been changed.  It's useful for 
::      watching for malware and for keeping an eye on system performance.
::
::
:: Synopsis:
::
::      GetTaskList
::
::      <No arguments required>
::
::
:: Additional Information:
::
::      This procedure creates a file named for the current date and time, and
::      located in your user profile folder under a Log subfolder 
::      (e.g., C:\Users\username\Log).
::
::      The filename is formatted as follows:
::
::      TaskList_YYYY_MM_DD_HH_MM_SS.log
::
::-=============================================================================
::
::  Start of process.
::
        PUSHD "%TEMP%"
::
        SET EXIT_STATUS=0
::
::  Cover the case where the system is not logged-in
::
        IF "%USERPROFILE%" == "C:\Users\Default" SET USERPROFILE=C:\Users\%USERNAME%
::
::  Create the log folder if it doesn't exist.
::
        MD "%USERPROFILE%\Log" >nul 2>&1
::
::  Craft the filename
::
        SHOWTIME "SET _TL_Filename=TaskList_%%Y_%%m_%%d_%%H_%%M_%%S.log" >_TL_Doit.bat
        CALL _TL_Doit.bat
::
        IF NOT "%_TL_Filename" == "" GOTO DO_TL
::
        ECHO TaskList filename could not be generated.
        SET EXIT_STATUS=4
        GOTO END_OF_PROCEDURE
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
:DO_TL
::
        ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO TaskList /V /FO:CSV /NH (processes running):>>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        TaskList /V /FO:CSV /NH | gsort -f >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
::
        ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO TaskList /SVC /FO:CSV /NH (services running):>>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        TaskList /SVC /FO:CSV /NH | sed -r -e "/\"N\/A\"$/d" | gsort -f >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
::
        ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO TaskList /M /FO:CSV /NH (modules loaded):>>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        TaskList /M /FO:CSV /NH | sed -r -e "/\"N\/A\"$/d" | gsort -f >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
        ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO SCHTASKS /Query /FO CSV (states of all scheduled tasks):>>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        SCHTASKS /Query /FO CSV | sed -e "/\"TaskName\"\,\"Next Run Time\"\,\"Status\"/d" >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
        ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO SC qc (configurations of all services):>>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        SC query state= all | grep "SERVICE_NAME: " | gsort -f | sed -r -e "s/^SERVICE_NAME: /SC qc \"/g" -e "s/$/\"/g" >"%TEMP%\_TL_Doit.bat"
        CALL "%TEMP%\_TL_Doit.bat" >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
        ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO WMIC qfe list (list of all installed updates):>>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        WMIC qfe list >"%TEMP%\_TL_ListOfInstalledUpdates.txt"
        TYPE "%TEMP%\_TL_ListOfInstalledUpdates.txt" >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
        ECHO. >>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
        ECHO ------------------------------------------------------------------------------------------->>"%USERPROFILE%\Log\%_TL_Filename%" 2>&1
::
:: = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
::
:END_OF_PROCEDURE
::
        DEL /Q "%TEMP%\_TL_Doit.bat" "%TEMP%\_TL_ListOfInstalledUpdates.txt" >nul 2>&1
        SET _TL_Filename=
::
        POPD
::
        EXIT %EXIT_STATUS%
::
::==============================================================================
::
::  End of file.
::
::==============================================================================
